class ParslBaseExecutor(object):

    def __init__(self, config, items, function, accumulator, workers, status, unit, desc):
        # create dfk

        # prepare the processor

        # submit jobs

        # collect them

        # reset?

        # kill the dfk?

        raise NotImplementedError
